@@ -133,7 +133,8 @@ def split_video_from_stamps(
         filename_tmpl='video_{start_frame:05}_{end_frame:05}.mp4',
         show_progress=True,
         parallel_process=False,
-        n_jobs=8):
+        n_jobs=8,
+        hflip=False, vflip=False):
     if len(start_stamps) != len(end_stamps):
         raise RuntimeError(
             'Length not much len(start_stamps) != len(end_stamps)'
@@ -159,7 +160,8 @@ def split_video_from_stamps(
                 start_stamps, end_stamps, output_paths)),
                                          total=len(output_paths),
                                          disable=show_progress is False):
-            split_video(video_file_path, video_out, start_time=s, end_time=e)
+            split_video(video_file_path, video_out, start_time=s, end_time=e,
+                        hflip=hflip, vflip=vflip)
     else:
         cpu_count = multiprocessing.cpu_count()
         if n_jobs == -1 or n_jobs == 'full':
@@ -170,7 +172,8 @@ def split_video_from_stamps(
         for i, (s, e, video_out) in enumerate(zip(
                 start_stamps, end_stamps, output_paths)):
             p.apply_async(split_video,
-                          args=(video_file_path, video_out, s, e))
+                          args=(video_file_path, video_out, s, e,
+                                hflip, vflip))
         p.close()
         p.join()
     return output_paths
